@@ -57,18 +57,18 @@ define!({
         pub raw: JsWord,
     }
 
-    pub enum DeclarationProperty {
-        Ident(Ident),
-        DashedIdent(DashedIdent),
-    }
-
     pub struct Declaration {
         pub span: Span,
-        pub property: DeclarationProperty,
+        pub name: DeclarationName,
         pub value: Vec<Value>,
         pub important: Option<Span>,
     }
 
+    pub enum DeclarationName {
+        Ident(Ident),
+        DashedIdent(DashedIdent),
+    }
+
     pub struct QualifiedRule {
         pub span: Span,
         pub prelude: SelectorList,
@@ -113,8 +113,6 @@ define!({
 
         Tokens(Tokens),
 
-        AtText(AtTextValue),
-
         Url(Url),
     }
 
@@ -171,12 +169,6 @@ define!({
         pub right: Option<Number>,
     }
 
-    pub struct AtTextValue {
-        pub span: Span,
-        pub name: Ident,
-        pub block: Option<SimpleBlock>,
-    }
-
     pub struct Url {
         pub span: Span,
         pub name: Ident,
@@ -191,6 +183,8 @@ define!({
 
     pub struct UrlValueRaw {
         pub span: Span,
+        pub before: JsWord,
+        pub after: JsWord,
         pub value: JsWord,
         pub raw: JsWord,
     }
